@@ -2,14 +2,14 @@
 
 import argparse
 import json
+import logging
 import os
 import subprocess
 import sys
 from contextlib import ExitStack
 
 from .job import define_jobs
-from .log import edebug, edie, eerror, einfo
-from .test import run_testing
+from .test import run_cmd, run_testing
 from .tmp import get_etc_portage_tmp_file
 
 
@@ -47,6 +47,7 @@ def process_args(sysargs):
 
     optional.add_argument(
         "--fail-fast",
+        "-ff",
         action="store_true",
         required=False,
         help="Exit on first failure. Useful to inspect fail logs. Default: False.",
@@ -80,6 +81,7 @@ def process_args(sysargs):
 
     optional.add_argument(
         "--append-required-use",
+        "-aru",
         action="store",
         type=str,
         required=False,
@@ -88,6 +90,7 @@ def process_args(sysargs):
 
     optional.add_argument(
         "--max-use-combinations",
+        "-muc",
         action="store",
         type=int,
         required=False,
@@ -97,6 +100,7 @@ def process_args(sysargs):
 
     optional.add_argument(
         "--use-flags-scope",
+        "-ufs",
         action="store",
         type=str,
         required=False,
@@ -107,6 +111,7 @@ def process_args(sysargs):
 
     optional.add_argument(
         "--test-feature-scope",
+        "-tfs",
         action="store",
         type=str,
         required=False,
@@ -123,6 +128,14 @@ def process_args(sysargs):
         help="Save report in JSON format under specified path.",
     )
 
+    optional.add_argument(
+        "--slow",
+        action="store_true",
+        required=False,
+        help="Run tests in slow mode, which takes more time.",
+        default=False,
+    )
+
     optional.add_argument(
         "--prefix",
         action="store",
@@ -142,20 +155,39 @@ def process_args(sysargs):
 
     optional.add_argument(
         "--extra-env-file",
+        "-eef",
         action="append",
         type=str,
         required=False,
         help="Extra /etc/portage/env/ file name, to be used while testing packages. Can be passed multile times.",
     )
 
+    optional.add_argument(
+        "--oneshot",
+        "-1",
+        action="store_true",
+        default=False,
+        required=False,
+        help="Shortcut to append --oneshot/-1 to emerge command.",
+    )
+
     optional.add_argument(
         "--append-emerge",
+        "-ae",
         action="store",
         type=str,
         required=False,
         help="Append flags or parameters to the actual emerge call.",
     )
 
+    optional.add_argument(
+        "--quiet",
+        action="store_true",
+        required=False,
+        help="Hide subprocess output unless there's an error. Default: False.",
+        default=False,
+    )
+
     args, extra_args = parser.parse_known_args(sysargs)
     if extra_args:
         if extra_args[0] != "--":
@@ -167,8 +199,12 @@ def process_args(sysargs):
     if len(sysargs) == 0:
         parser.print_help(sys.stderr)
         sys.exit(1)
-    if args.debug:
-        edebug("{}".format(args))
+
+    # Configure logging
+    log_level = logging.DEBUG if args.debug else logging.INFO
+    logging.basicConfig(level=log_level, format="[%(levelname)s] >>> %(message)s")
+
+    logging.debug("{}".format(args))
     return args, extra_args
 
 
@@ -198,7 +234,8 @@ def pkg_testing_tool(args, extra_args):
         for ebuild in args.file:
             # test that file ends in ".ebuild"
             if not ebuild.endswith(".ebuild"):
-                edie("File {} does not end with '.ebuild'.".format(ebuild))
+                logging.critical("File {} does not end with '.ebuild'.".format(ebuild))
+                sys.exit(1)
             repo = os.path.dirname(
                 os.path.dirname(os.path.dirname(os.path.abspath(ebuild)))
             )
@@ -222,9 +259,13 @@ def pkg_testing_tool(args, extra_args):
                 "=" + category + "/" + package_version + "::" + repo_name
             ]
             # make sure we have the right manifest already
-            if args.debug:
-                edebug(f"ebuild {ebuild} manifest")
-            subprocess.run(["ebuild", ebuild, "manifest"])
+            logging.debug(f"ebuild {ebuild} manifest")
+            run_cmd(
+                ["ebuild", ebuild, "manifest"],
+                os.environ.copy(),
+                args.quiet,
+                args.pretend,
+            )
 
         jobs = []
 
@@ -242,9 +283,9 @@ def pkg_testing_tool(args, extra_args):
 
         padding = max(len(i["cpv"]) for i in jobs) + 3
 
-        einfo("Following testing jobs will be executed:")
+        logging.info("Following testing jobs will be executed:")
         for job in jobs:
-            print(
+            logging.info(
                 "{cpv:<{padding}} USE: {use_flags}{test_feature}".format(
                     cpv=job["cpv"],
                     use_flags=(
@@ -266,7 +307,7 @@ def pkg_testing_tool(args, extra_args):
         i = 0
         for job in jobs:
             i += 1
-            einfo(
+            logging.info(
                 "Running ({i} of {max_i}) {cpv} with USE: {use_flags}{test_feature}".format(
                     i=i,
                     max_i=len(jobs),
@@ -283,7 +324,7 @@ def pkg_testing_tool(args, extra_args):
             )
             results.append(run_testing(job, args))
             if args.fail_fast and results[-1]["exit_code"] != 0:
-                eerror("Exiting due to --fail-fast.")
+                logging.error("Exiting due to --fail-fast.")
                 break
 
     failures = []
@@ -296,20 +337,21 @@ def pkg_testing_tool(args, extra_args):
             report.write(json.dumps(results, indent=4, sort_keys=True))
 
     if len(failures) > 0:
-        eerror("Not all runs were successful.")
+        logging.error("Not all runs were successful.")
         for entry in failures:
-            print(
+            logging.error(
                 "atom: {atom}, USE flags: '{use_flags}'".format(
                     atom=entry["atom"], use_flags=entry["use_flags"]
                 )
             )
         sys.exit(1)
     else:
-        einfo("All good.")
+        logging.info("All good.")
 
 
 def run(sysargs):
     args, extra_args = process_args(sysargs)
+
     pkg_testing_tool(args, extra_args)
 
 
